@@ -1,5 +1,7 @@
 # encoding: utf-8
 
+"""TurboGears extension startup and shutdown interface."""
+
 import logging
 log = logging.getLogger("turbomail")
 
@@ -10,10 +12,16 @@ from turbomail.exceptions import *
 from turbomail.pool import MailPool
 
 
-__all__ = ['start_extension', 'stop_extension']
+__all__ = ['start_extension', 'shutdown_extension']
 
 
 def start_extension():
+	"""TurboGears extension startup.
+	
+	Exits immediately if TurboMail is not enabled and creates a MailPool
+	instance if all is well.
+	"""
+	
 	if not turbogears.config.get("mail.on", False):
 		return
 	
@@ -37,6 +45,12 @@ def start_extension():
 
 
 def shutdown_extension():
+	"""TurboGears extension shutdown.
+	
+	Exits immediately if TurboMail is not enabled and shuts down the
+	MailPool object safely.
+	"""
+	
 	if not turbogears.config.get("mail.on", False):
 		return
 
